@@ -107,7 +107,10 @@ func (s *SourceStateCommand) SourceRelPath() SourceRelPath {
 }
 
 // TargetStateEntry returns s's target state entry.
-func (s *SourceStateCommand) TargetStateEntry(destSystem System, destDirAbsPath AbsPath) (TargetStateEntry, error) {
+func (s *SourceStateCommand) TargetStateEntry(
+	destSystem System,
+	destDirAbsPath AbsPath,
+) (TargetStateEntry, error) {
 	return &TargetStateModifyDirWithCmd{
 		cmd:           s.cmd,
 		forceRefresh:  s.forceRefresh,
@@ -144,7 +147,10 @@ func (s *SourceStateDir) SourceRelPath() SourceRelPath {
 }
 
 // TargetStateEntry returns s's target state entry.
-func (s *SourceStateDir) TargetStateEntry(destSystem System, destDirAbsPath AbsPath) (TargetStateEntry, error) {
+func (s *SourceStateDir) TargetStateEntry(
+	destSystem System,
+	destDirAbsPath AbsPath,
+) (TargetStateEntry, error) {
 	return s.targetStateEntry, nil
 }
 
@@ -188,9 +194,15 @@ func (s *SourceStateFile) SourceRelPath() SourceRelPath {
 }
 
 // TargetStateEntry returns s's target state entry.
-func (s *SourceStateFile) TargetStateEntry(destSystem System, destDirAbsPath AbsPath) (TargetStateEntry, error) {
+func (s *SourceStateFile) TargetStateEntry(
+	destSystem System,
+	destDirAbsPath AbsPath,
+) (TargetStateEntry, error) {
 	if s.targetStateEntryFunc != nil {
-		s.targetStateEntry, s.targetStateEntryErr = s.targetStateEntryFunc(destSystem, destDirAbsPath)
+		s.targetStateEntry, s.targetStateEntryErr = s.targetStateEntryFunc(
+			destSystem,
+			destDirAbsPath,
+		)
 		s.targetStateEntryFunc = nil
 	}
 	return s.targetStateEntry, s.targetStateEntryErr
@@ -222,7 +234,10 @@ func (s *SourceStateRemove) SourceRelPath() SourceRelPath {
 }
 
 // TargetStateEntry returns s's target state entry.
-func (s *SourceStateRemove) TargetStateEntry(destSystem System, destDirAbsPath AbsPath) (TargetStateEntry, error) {
+func (s *SourceStateRemove) TargetStateEntry(
+	destSystem System,
+	destDirAbsPath AbsPath,
+) (TargetStateEntry, error) {
 	return &TargetStateRemove{}, nil
 }
 
