@@ -54,9 +54,12 @@ func TestZIPWriterSystem(t *testing.T) {
 		b := &bytes.Buffer{}
 		zipWriterSystem := NewZIPWriterSystem(b, time.Now().UTC())
 		persistentState := NewMockPersistentState()
-		assert.NoError(t, s.applyAll(zipWriterSystem, system, persistentState, EmptyAbsPath, ApplyOptions{
-			Filter: NewEntryTypeFilter(EntryTypesAll, EntryTypesNone),
-		}))
+		assert.NoError(
+			t,
+			s.applyAll(zipWriterSystem, system, persistentState, EmptyAbsPath, ApplyOptions{
+				Filter: NewEntryTypeFilter(EntryTypesAll, EntryTypesNone),
+			}),
+		)
 		assert.NoError(t, zipWriterSystem.Close())
 
 		r, err := zip.NewReader(bytes.NewReader(b.Bytes()), int64(b.Len()))
